# API


* [artifician package](API.md)


    * [Subpackages](API.md#subpackages)


        * [artifician.processors package](artifician.processors.md)


            * [Submodules](artifician.processors.md#submodules)


    * [Submodules](API.md#submodules)


        * [artifician.dataset module](artifician.dataset.md)


            * [`Dataset`](artifician.dataset.md#artifician.dataset.Dataset)


        * [artifician.feature_definition module](artifician.feature_definition.md)


            * [`FeatureDefinition`](artifician.feature_definition.md#artifician.feature_definition.FeatureDefinition)
